/// <reference types="react" />
import type { BaseDialogProps } from "@react-md/dialog";
import type { LabelRequiredForA11y } from "@react-md/utils";
declare type AllowedDialogProps = Omit<BaseDialogProps, "role" | "type" | "modal" | "forceContainer">;
/**
 * The location that the sheet should be located within the viewport.
 */
export declare type SheetPosition = "top" | "right" | "bottom" | "left";
/**
 * The size to use for sheets that have been positioned left or right. The
 * default supported values are:
 *
 * - none - the size is based on content, but is still limited to the viewport
 *   width so that the horizontal scrolling will not occur within the page. No
 *   limits added to sizing.
 * - touch - the `min-width` is set to be the entire viewport width minus a
 *   touchable area and `max-width` is set to `20rem` and is normally
 *   recommended for mobile devices.
 * - static - the width is set to a static `16rem` and generally used for
 *   landscape tablets and desktops.
 * - media - automatically switches between "touch" and "static" based on css
 *   media queries. (this is the default)
 */
export declare type SheetHorizontalSize = "none" | "media" | "touch" | "static";
/**
 * The size to use for sheets that have been positioned top or bottom. The
 * supported sizes are:
 *
 * - none - the size is based on content and is limited to the viewport
 *   height.
 * - touch - the size is based on content and is limited to the viewport
 *   height with a touchable area to close the sheet.
 * - recommended - the material design recommended sizing that forces a
 *   max-height of 50vh and min-height of 3.5rem
 */
export declare type SheetVerticalSize = "none" | "touch" | "recommended";
export interface BaseSheetProps extends AllowedDialogProps {
    /**
     * The role that the sheet should be rendered as. You'll normally want to keep
     * this as the default of `"dialog"` unless you are implementing a mobile
     * sheet menu.
     *
     * Note: Setting this to `"menu"` **will not** provide the menu keyboard
     * accessibility automatically.
     */
    role?: "dialog" | "menu" | "none";
    /** {@inheritDoc SheetPosition} */
    position?: SheetPosition;
    /** {@inheritDoc SheetHorizontalSize} */
    horizontalSize?: SheetHorizontalSize;
    /** {@inheritDoc SheetVerticalSize} */
    verticalSize?: SheetVerticalSize;
}
export declare type SheetProps = LabelRequiredForA11y<BaseSheetProps>;
/**
 * The Sheet component is an extension of the `Dialog` except that it is fixed
 * to the edges of the viewport instead of centered or full page. This component
 * is great for rendering a navigation tree or menus on mobile devices.
 */
export declare const Sheet: import("react").ForwardRefExoticComponent<SheetProps & import("react").RefAttributes<HTMLDivElement>>;
export {};
